pub enum EventStreamConfigResponse {
Disabled,
Enabled(Metrics),
WasAlreadyEnabled,
}Expand description
A Sandstorm event stream config response.
Variants
Disabled
Indicates that the event stream is now disabled. If this is a response to a request to enable it, then it is the server refusing to enable the event stream.
Enabled(Metrics)
Indicates that the event stream is now enabled, as well as a metrics snapshot at the time the events were enabled (this can be used to infer accurate real time metrics).
WasAlreadyEnabled
Indicates that the event stream was already enabled.